@@ -1,3 +1,4 @@
+from aiogram.dispatcher.handler import CancelHandler
 from aiogram.dispatcher.middlewares import BaseMiddleware
 from aiogram.types import Update
 
@@ -10,4 +11,7 @@ class BapMiddleware(BaseMiddleware):
         super(BapMiddleware, self).__init__()
 
     async def on_process_update(self, update: Update, data):
-        await self._bap.handle_update(update.to_python())
+        needUpdate = await self._bap.handle_update(update.to_python())
+
+        if not needUpdate:
+            raise CancelHandler()
